Learn R Programming

chessR (version 1.5.2)

lichess_leaderboard: Get top players on Lichess leaderboards

Description

This function takes in two parameters; how many players you want returned (max 200) and the speed variant. The result is a data frame for each game type

Usage

lichess_leaderboard(top_n_players, speed_variant)

Value

a dataframe of the lichess top players based on speed_variant and top_n_players selected

Arguments

top_n_players

The number of players (up to 200) you want returned

speed_variant

A valid lichess speed variant to return the leaderboard for

Details

The leaderboard speed variant options include:

"ultraBullet", "bullet", "blitz", "rapid", "classical", "chess960", "crazyhouse", "antichess" , "atomic", "horde", "kingOfTheHill", "racingKings", "threeCheck"

Examples

Run this code
if (FALSE) {
top10_blitz <- lichess_leaderboard(top_n_players = 10, speed_variant = "blitz")
leaderboards <- purrr::map2_df(top_n_players = 10, c("ultraBullet", "bullet"), lichess_leaderboard)
}

Run the code above in your browser using DataLab